pub struct SessionSetupView {
stack: TemplateChild<Stack>,
session: WeakRef<Session>,
crypto_identity_view: OnceCell<CryptoIdentitySetupView>,
recovery_view: OnceCell<CryptoRecoverySetupView>,
session_handler: RefCell<Option<SignalHandlerId>>,
security_handler: RefCell<Option<SignalHandlerId>>,
}Fields
stack: TemplateChild<Stack>session: WeakRef<Session>The current session.
crypto_identity_view: OnceCell<CryptoIdentitySetupView>The crypto identity view.
recovery_view: OnceCell<CryptoRecoverySetupView>The recovery view.
session_handler: RefCell<Option<SignalHandlerId>>security_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl SessionSetupView
impl SessionSetupView
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SessionSetupView
impl SessionSetupView
Sourcefn visible_stack_page(&self) -> SessionSetupPage
fn visible_stack_page(&self) -> SessionSetupPage
The visible page of the stack.
Sourcefn crypto_identity_view(&self) -> &CryptoIdentitySetupView
fn crypto_identity_view(&self) -> &CryptoIdentitySetupView
The crypto identity view.
Sourcefn recovery_view(&self) -> &CryptoRecoverySetupView
fn recovery_view(&self) -> &CryptoRecoverySetupView
The recovery view.
Sourcefn set_session(&self, session: &Session)
fn set_session(&self, session: &Session)
Set the current session.
Sourcefn check_session_setup(&self)
fn check_session_setup(&self)
Check whether we need to show the session setup.
Sourcefn check_recovery(&self, enable_only: bool)
fn check_recovery(&self, enable_only: bool)
Check whether we need to enable or set up recovery.
Sourcefn switch_to_recovery(&self)
fn switch_to_recovery(&self)
Switch to the recovery view.
Sourcefn focus_default_widget(&self)
fn focus_default_widget(&self)
Focus the proper widget for the current page.
fn emit_completed(&self)